@@ -1,6 +1,7 @@
-#include <QtGui/QApplication>
+#include <QSettings>
+#include <QApplication>
 
-#include <rx/columbus/ColumbusController.h>
+#include "ApplicationController.h"
 
 #include "ui/MainWindow.h"
 
@@ -12,7 +13,7 @@ int main(int argc, char *argv[])
     QApplication::setApplicationVersion("0.8.1");
 
     QApplication            application (argc, argv);
-    ColumbusController   controller;
+    ApplicationController   controller;
 
     MainWindow              window;
     window.initialize(&controller);
