@@ -34,7 +34,7 @@ ColumbusDialogLogging::~ColumbusDialogLogging()
     delete this->d;
 }
 
-void ColumbusDialogLogging::setController(ColumbusController *controller)
+void ColumbusDialogLogging::setController(ApplicationController *controller)
 {
     ColumbusDialog::setController(controller);
     if(this->layout()->isEmpty())
@@ -66,7 +66,6 @@ void ColumbusDialogLogging::setupUi()
     d->isRunOnStart = new QCheckBox(tr("Run on Startup"), this);
 
     d->format = new QMaemo5ValueButton(tr("Format"), this);
-    //d->format->setValueLayout(QMaemo5ValueButton::ValueUnderTextCentered);
     d->format->setPickSelector(d->formatSelector);
 
     this->layout()->addWidget(d->isEnabled);
