@@ -14,7 +14,7 @@ public:
                 ~ColumbusDialogOptions  ();
 
 public slots:
-    void         setController (ColumbusController *controller);
+    void         setController (ApplicationController *controller);
 
 private:
     void         addToggle          (const QString &key);
