@@ -10,7 +10,7 @@ ColumbusDialogTools::ColumbusDialogTools(QWidget *parent)
     this->setWindowTitle(tr("Tools"));
 }
 
-void ColumbusDialogTools::setController(ColumbusController *controller)
+void ColumbusDialogTools::setController(ApplicationController *controller)
 {
     ColumbusDialog::setController(controller);
 
