@@ -3,8 +3,6 @@
 
 #include "widgets/ColumbusDialog.h"
 
-#include <QMaemo5ValueButton>
-
 class ColumbusDialogTools : public ColumbusDialog
 {
     Q_OBJECT
@@ -12,10 +10,10 @@ class ColumbusDialogTools : public ColumbusDialog
 public:
     explicit ColumbusDialogTools(QWidget *parent = 0);
 
-    void setController(ColumbusController *controller);
+    void setController(ApplicationController *controller);
 
 private:
-    void                setupUi         ();
+    void setupUi();
 };
 
 #endif // COLUMBUSDIALOGTOOLS_H
