@@ -19,7 +19,7 @@ class ColumbusStatusViewPrivate
 {
 public:
     // Application controller reference.
-    ColumbusController   *controller;
+    ApplicationController   *controller;
 
     // View widget components.
     CompassSlide            *compass;
@@ -72,6 +72,8 @@ ColumbusStatusView::ColumbusStatusView(QWidget *parent)
     d->compassAnimation->setEasingCurve(QEasingCurve::InOutQuad);
 
     QObject::connect(d->compass, SIGNAL(headingChanged(double)), d->satelliteView, SLOT(setHeading(double)));
+    QObject::connect(d->compass, SIGNAL(bearingChanged(double)), d->satelliteView, SLOT(setBearing(double)));
+    QObject::connect(d->compass, SIGNAL(bearingShownChanged(bool)), d->satelliteView, SLOT(setBearingShown(bool)));
 
     // Heading & Speed Detail.
     QVBoxLayout *svbox  = new QVBoxLayout();
@@ -143,7 +145,7 @@ QString ColumbusStatusView::friendlyName() const
     return friendlyName;
 }
 
-void ColumbusStatusView::setController(ColumbusController *controller)
+void ColumbusStatusView::setController(ApplicationController *controller)
 {
     if(d->controller != NULL)
     {
@@ -231,6 +233,17 @@ void ColumbusStatusView::onPositionUpdated(const QGeoPositionInfo &posinfo)
     QString latitude = model->currentLatitude();
     QString longitude = model->currentLongitude();
 
+    if(d->controller->waypoints()->destination().isValid())
+    {
+        ColumbusWaypoint waypoint = d->controller->waypoints()->waypoint(d->controller->waypoints()->destination());
+        d->compass->setBearing(posinfo.coordinate().azimuthTo(waypoint.coordinate()));
+        if(!d->compass->isBearingShown()) d->compass->setBearingShown(true);
+    }
+    else
+    {
+        if(d->compass->isBearingShown()) d->compass->setBearingShown(false);
+    }
+
     if(direction != d->headingIndicator->value())
     {
         if(d->compassAnimation->state() == QPropertyAnimation::Running) d->compassAnimation->stop();
