@@ -9,7 +9,7 @@
 class ColumbusTrackViewPrivate
 {
 public:
-    ColumbusController *controller;
+    ApplicationController *controller;
 
     QPropertyAnimation *zoomAnimation;
     QPropertyAnimation *rotationAnimation;
@@ -69,10 +69,13 @@ ColumbusTrackView::ColumbusTrackView(QWidget *parent)
     d->altitude      = ValueLabel("-");
     d->tripDistance  = ValueLabel("-");
 
+    d->altitude->hide();
+    d->tripDistance->hide();
+
     posl->addRow(tr("Latitude"), d->latitude);
     posl->addRow(tr("Longitude"), d->longitude);
-    posl->addRow(tr("Altitude"), d->altitude);
-    posl->addRow(tr("Distance"), d->tripDistance);
+    //posl->addRow(tr("Altitude"), d->altitude);
+    //posl->addRow(tr("Distance"), d->tripDistance);
 
     d->compass = new CompassDial(this);
     d->compass->setFixedWidth(164);
@@ -117,7 +120,7 @@ QString ColumbusTrackView::friendlyName() const
     return friendlyName;
 }
 
-void ColumbusTrackView::setController(ColumbusController *controller)
+void ColumbusTrackView::setController(ApplicationController *controller)
 {
     if(d->controller != NULL)
     {
@@ -129,7 +132,16 @@ void ColumbusTrackView::setController(ColumbusController *controller)
 
     if(d->controller != NULL)
     {
-        d->trackView->setModel(d->controller->model());
+        if(d->controller->model() != NULL)
+        {
+            d->trackView->setModel(d->controller->model());
+        }
+
+        if(d->controller->waypoints() != NULL)
+        {
+            d->trackView->setWaypoints(d->controller->waypoints());
+        }
+
         d->speedIndicator->setUnitIndicator(d->controller->model()->speedUnits());
 
         QObject::connect(d->controller->model(), SIGNAL(distanceUpdated(qreal)),
@@ -168,7 +180,7 @@ void ColumbusTrackView::onDistanceUpdated(qreal distance)
     this->d->tripDistance->setText(QString::number(distance, 'f', 2) + " <sub>" + d->controller->model()->distanceUnits() + "</sub>");
 }
 
-void ColumbusTrackView::onPositionUpdated(const QGeoPositionInfo&)
+void ColumbusTrackView::onPositionUpdated(const QGeoPositionInfo &posinfo)
 {
     const ColumbusModel *model = d->controller->model();
 
@@ -198,6 +210,18 @@ void ColumbusTrackView::onPositionUpdated(const QGeoPositionInfo&)
         d->speedIndicator->setValue(model->maximumSpeed());
     }
 
+    if(d->controller->waypoints()->destination().isValid())
+    {
+        ColumbusWaypoint waypoint = d->controller->waypoints()->waypoint(d->controller->waypoints()->destination());
+        d->compass->setBearing(posinfo.coordinate().azimuthTo(waypoint.coordinate()));
+
+        if(!d->compass->isBearingShown()) d->compass->setBearingShown(true);
+    }
+    else
+    {
+        if(d->compass->isBearingShown()) d->compass->setBearingShown(false);
+    }
+
     qreal nrot = direction;
     qreal crot = d->rotationAnimation->targetObject()->property(d->rotationAnimation->propertyName()).toReal();
 
