@@ -18,7 +18,7 @@ public:
             ~ColumbusTrackView  ();
 
     QString  friendlyName   () const;
-    void     setController  (ColumbusController *controller);
+    void     setController  (ApplicationController *controller);
 
 public slots:
     void     cycleSpeedIndicator    ();
