@@ -1,10 +1,10 @@
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
-#include "widgets/ColumbusDialog.h"
-
 #include "ApplicationViewSwitcher.h"
 
+#include "widgets/ColumbusDialog.h"
+
 #include <rx/columbus/ColumbusController.h>
 
 #include <QMainWindow>
@@ -20,7 +20,7 @@ class MainWindow : public QMainWindow
 public:
     explicit     MainWindow     (QWidget *parent = 0);
 
-    void         initialize     (ColumbusController *controller);
+    void         initialize     (ApplicationController *controller);
 
 signals:
     void         onLandscape    ();
@@ -52,6 +52,8 @@ private slots:
 
     void         onConfigUpdated        (const QString &key, QVariant value);
 
+    void         onAnimationFinished    ();
+
 protected:
     void         setupX11Keys();
 
@@ -62,9 +64,12 @@ private:
 
     bool         eventFilter    (QObject *object, QEvent *event);
 
+    // Animation state
+    bool         isWaitingToHide;
+
     // Reference to application controller instance.
-    ColumbusController   *m_Controller;
-    ColumbusController   *m_ControllerSuspended;
+    ApplicationController   *m_Controller;
+    ApplicationController   *m_ControllerSuspended;
 
     // Current screen lock state
     QString m_ScreenLockState;
