@@ -5,6 +5,8 @@ class AbstractCompassPrivate
 public:
     double heading;
     double bearing;
+
+    bool   isBearingShown;
 };
 
 AbstractCompass::AbstractCompass(QWidget *parent)
@@ -13,6 +15,7 @@ AbstractCompass::AbstractCompass(QWidget *parent)
     this->d = new AbstractCompassPrivate;
     d->heading = 0.0f;
     d->bearing = 0.0f;
+    d->isBearingShown = false;
 }
 
 AbstractCompass::~AbstractCompass()
@@ -25,11 +28,6 @@ double AbstractCompass::heading() const
     return d->heading;
 }
 
-double AbstractCompass::bearing() const
-{
-    return d->bearing;
-}
-
 void AbstractCompass::setHeading(double heading)
 {
     d->heading = heading;
@@ -38,6 +36,11 @@ void AbstractCompass::setHeading(double heading)
     emit this->headingChanged(heading);
 }
 
+double AbstractCompass::bearing() const
+{
+    return d->bearing;
+}
+
 void AbstractCompass::setBearing(double bearing)
 {
     d->bearing = bearing;
@@ -45,3 +48,16 @@ void AbstractCompass::setBearing(double bearing)
 
     emit this->bearingChanged(bearing);
 }
+
+bool AbstractCompass::isBearingShown() const
+{
+    return d->isBearingShown;
+}
+
+void AbstractCompass::setBearingShown(bool isShown)
+{
+    d->isBearingShown = isShown;
+    this->update();
+
+    emit this->bearingShownChanged(isShown);
+}
