@@ -9,8 +9,9 @@ class AbstractCompass : public QWidget
 {
     Q_OBJECT
 
-    Q_PROPERTY(double heading READ heading WRITE setHeading)
-    Q_PROPERTY(double bearing READ bearing WRITE setBearing)
+    Q_PROPERTY(double heading READ heading WRITE setHeading NOTIFY headingChanged)
+    Q_PROPERTY(double bearing READ bearing WRITE setBearing NOTIFY bearingChanged)
+    Q_PROPERTY(bool isBearingShown READ isBearingShown WRITE setBearingShown NOTIFY bearingShownChanged)
 
 public:
     explicit     AbstractCompass    (QWidget *parent = 0);
@@ -18,14 +19,17 @@ public:
 
     double       heading            () const;
     double       bearing            () const;
+    bool         isBearingShown     () const;
 
 signals:
     void         headingChanged     (double heading);
     void         bearingChanged     (double bearing);
+    void         bearingShownChanged(bool isShown);
 
 public slots:
     void         setHeading         (double heading);
     void         setBearing         (double bearing);
+    void         setBearingShown    (bool isShown);
 
 protected:
     virtual void paintEvent         (QPaintEvent *event) = 0;
