@@ -3,7 +3,7 @@
 class ColumbusDialogPrivate
 {
 public:
-    ColumbusController *controller;
+    ApplicationController *controller;
 };
 
 ColumbusDialog::ColumbusDialog(QWidget *parent)
@@ -17,12 +17,12 @@ ColumbusDialog::~ColumbusDialog()
     delete this->d;
 }
 
-ColumbusController* ColumbusDialog::controller() const
+ApplicationController* ColumbusDialog::controller() const
 {
     return d->controller;
 }
 
-void ColumbusDialog::setController(ColumbusController *controller)
+void ColumbusDialog::setController(ApplicationController *controller)
 {
     d->controller = controller;
 }
