@@ -6,10 +6,14 @@
 
 #include "AbstractCompass.h"
 
+class CompassSlidePrivate;
+
 class CompassSlide : public AbstractCompass
 {
     Q_OBJECT
+
     Q_ENUMS(DisplayMode)
+
     Q_PROPERTY(DisplayMode displayMode READ displayMode WRITE setDisplayMode)
 
 public:
@@ -31,7 +35,7 @@ protected:
     virtual void     draw           (QPainter *painter);
 
 private:
-    DisplayMode      m_DisplayMode;
+    CompassSlidePrivate *d;
 };
 
 #endif // COMPASSSLIDE_H
