@@ -3,7 +3,7 @@
 
 #include "AbstractChart.h"
 
-#include "data/TripModel.h"
+#include <rx/columbus/ColumbusModel.h>
 
 class SpeedGraphPrivate;
 
@@ -14,10 +14,10 @@ class SpeedGraph : public AbstractChart
 public:
     explicit SpeedGraph(QWidget *parent = 0);
 
-    TripModel* model() const;
+    ColumbusModel* model() const;
 
 public slots:
-    void setModel(TripModel *model);
+    void setModel(ColumbusModel *model);
 
 protected:
     void paintEvent(QPaintEvent *event);
