@@ -4,6 +4,7 @@
 #include <QWidget>
 
 #include <rx/columbus/ColumbusModel.h>
+#include <rx/columbus/ColumbusWaypointModel.h>
 
 class TrackViewPrivate;
 
@@ -11,7 +12,9 @@ class TrackView : public QWidget
 {
     Q_OBJECT
 
-    Q_PROPERTY(ColumbusModel* model READ model WRITE setModel NOTIFY modelUpdated)
+    Q_PROPERTY(ColumbusModel *model READ model WRITE setModel NOTIFY modelUpdated)
+    Q_PROPERTY(ColumbusWaypointModel *waypoints READ waypoints WRITE setWaypoints)
+
     Q_PROPERTY(qreal zoom READ zoom WRITE setZoom NOTIFY zoomUpdated)
     Q_PROPERTY(qreal rotation READ rotation WRITE setRotation NOTIFY rotationUpdated)
     Q_PROPERTY(QPointF position READ position WRITE setPosition NOTIFY positionUpdated)
@@ -21,6 +24,7 @@ public:
             ~TrackView();
 
     ColumbusModel* model();
+    ColumbusWaypointModel* waypoints();
 
     qreal zoom() const;
     qreal rotation() const;
@@ -35,6 +39,7 @@ signals:
 
 public slots:
     void setModel(ColumbusModel *model);
+    void setWaypoints(ColumbusWaypointModel *waypoints);
 
     void setZoom(qreal zoom);
     void setRotation(double rotation);
